@@ -16,7 +16,8 @@ class GraphvizTBFormatter(BaseFormatter):
     MATCH_FORMAT = '"m${table_no}_${priority_no}_${entry_no}" [ shape="diamond", fillcolor="#ddddff", peripheries=1, label="${match_exp}" ]'
     INSTRUCTION_OUTPUT_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ shape="record", fillcolor="#ffcccc", peripheries=1, label="{${actions}}" ]'
     INSTRUCTION_CONTROLLER_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ shape="record", fillcolor="#ffffcc", peripheries=1, label="{${actions}}" ]'
-    INSTRUCTION_RESUBMIT_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ shape="record", fillcolor="#ffffff", peripheries=1, label="{${actions}}" ]'
+    INSTRUCTION_RESUBMIT_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ style="dashed", shape="record", fillcolor="#ffffff", color="#0000ff", peripheries=1, label="{${actions}}" ]'
+    INSTRUCTION_DROP_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ shape="record", fillcolor="#cccccc", color="#ff0000", peripheries=1, label="{${actions}}" ]'
     INSTRUCTION_OTHER_FORMAT = '"l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ shape="record", fillcolor="#ffffff", peripheries=1, label="{${actions}}" ]'
     MATCH_TO_INSTRUCTION_FORMAT = '"m${table_no}_${priority_no}_${entry_no}" -> "l${table_no}_${priority_no}_${entry_no}_${instruction_no}" [ color="#0000CC", fontcolor="#663333", label="YES" ]'
     START_TO_PRIORITY_FORMAT = '"start${table_no}" -> "m${table_no}_${priority_no}_${entry_no}" [ lhead=cluster_t${table_no}_p${priority_no}, color="#000000", fontcolor="#663333", label="" ]'
@@ -149,6 +150,7 @@ node [
         self.instruction_output_template = string.Template(self.INSTRUCTION_OUTPUT_FORMAT)
         self.instruction_controller_template = string.Template(self.INSTRUCTION_CONTROLLER_FORMAT)
         self.instruction_resubmit_template = string.Template(self.INSTRUCTION_RESUBMIT_FORMAT)
+        self.instruction_drop_template = string.Template(self.INSTRUCTION_DROP_FORMAT)
         self.instruction_other_template = string.Template(self.INSTRUCTION_OTHER_FORMAT)
         self.match_to_instruction_template = string.Template(self.MATCH_TO_INSTRUCTION_FORMAT)
         self.start_to_priority_template = string.Template(self.START_TO_PRIORITY_FORMAT)
@@ -334,6 +336,10 @@ node [
         return self.instruction_resubmit_template.substitute({"table_no":table_no, "priority_no":priority_no, \
             "entry_no":entry_no, "instruction_no":instruction_no, "actions":actions})
 
+    def _format_instruction_drop(self, table_no, priority_no, entry_no, instruction_no, actions):
+        return self.instruction_drop_template.substitute({"table_no":table_no, "priority_no":priority_no, \
+            "entry_no":entry_no, "instruction_no":instruction_no, "actions":actions})
+
     def _format_instruction_other(self, table_no, priority_no, entry_no, instruction_no, actions):
         return self.instruction_other_template.substitute({"table_no":table_no, "priority_no":priority_no, \
             "entry_no":entry_no, "instruction_no":instruction_no, "actions":actions})
@@ -355,13 +361,15 @@ node [
             elif re.match(r'.* CONTROLLER:.*', actions) is not None:
                 formatted_str += "\n" + self.INDENT_IN_PRIORITY_BLOCK + \
                     self._format_instruction_controller(table_no, priority_no, entry_no, instruction_no, actions)
+            elif re.match(r'.* drop', actions) is not None:
+                formatted_str += "\n" + self.INDENT_IN_PRIORITY_BLOCK + \
+                    self._format_instruction_drop(table_no, priority_no, entry_no, instruction_no, actions)
             elif re.match(r'.* resubmit:\d+', actions) is not None or re.match(r'.* resubmit\(\d+,%s' % table_no, actions) is not None:
                 formatted_str += "\n" + self.INDENT_IN_PRIORITY_BLOCK + \
                     self._format_instruction_resubmit(table_no, priority_no, entry_no, instruction_no, actions)
                 self.resubmit_edges.append("\n" + self.INDENT_IN_TABLE \
                     + self._format_instruction_to_resubmit(table_no, priority_no, entry_no, instruction_no))
                 self.resubmit_loop = True
-#            elif re.match(r'.* resubmit.*', actions) is not None:
             elif self.util.d_push(re.match(r'.* resubmit\(\d*,(\d+)\)', actions)) is not None:
                 match = self.util.d_pop()
                 resubmit_table_no = match.group(1)
